<?php
/**
 * WeCodeArt Framework.
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package 	WeCodeArt Framework
 * @subpackage 	Support\CF7\Modules\Module
 * @copyright   Copyright (c) 2021, WeCodeArt Framework
 * @since 		5.0.0
 * @version		5.0.0
 */

namespace WeCodeArt\Support\Plugins\CF7\Modules;

defined( 'ABSPATH' ) || exit;

/**
 * Module
 */
abstract class Module {

	/**
	 * Module Name.
	 *
	 * @var string
	 */
	protected $name = '';

	/**
	 * Module Fields.
	 *
	 * @var mixed	(string|array)
	 */
	protected $fields = [];

	/**
	 * Register Module
	 */
	public function register() {
		if ( method_exists( $this, 'get_html' ) ) {
			remove_action( 'wpcf7_init', "wpcf7_add_form_tag_{$this->name}", 10, 0  );
			add_action( 'wpcf7_init', function() {
				wpcf7_add_form_tag( $this->fields, [ $this, 'get_html' ], $this->get_args() );
			}, 10, 0 );
			return;
		}

		return _doing_it_wrong(
			__CLASS__,
			sprintf( esc_html__( 'When extending %s, you must create a `get_html` method.', 'wecodeart' ), __CLASS__ ), 
			'5.0.0'
		); 
	}

	/**
	 * Include and render a field.
	 *
	 * @param 	object  $tag
	 * @return 	string 	Rendered block type output.
	 */
	// abstract public function get_html( $tag );

	/**
	 * Get Tag wrap classname
	 *
	 * @since   5.0.0
	 * @version	5.3.1
	 *
	 * @return  string
	 */
	public static function get_wrap_class( $tag, $extra = '' ) {
		$defaults = [ 'wpcf7-form-control-wrap', 'position-relative', $tag->name ];

		if( strpos( $extra, 'input-group' ) === false ) {
			$defaults[] = 'd-block';
		}
		
		$defaults = wp_parse_args( explode( ' ', $extra ), $defaults );

		return join( ' ', array_filter( $defaults ) );
	}

	/**
	 * Get Module args.
	 *
	 * @return array
	 */
	protected function get_args() {
		return [
			'name-attr' => true
		];
	}
}